/*
_npc.dm

this file controls all NPCs.  all NPCs should branch from the /npc tree.
It even includes a sales() proc that makes shopkeeping very easy.

It's rather long though, so i challenge you to study it, understand how it works, and make it better.
*/

npc
	parent_type = /mob

	NPC = TRUE

	var
		// NPCs won't sell item's that aren't in this tree.  As such, someone with /item/potion won't accept /items.
		// However, someone with /item will accept /item/potions.
		// To override this (If need-be), just modify the wont_accept list.
		sell_type = /item

		// wont_accept is treated very specifically.  If you want all of a certain branch of /item to be in here, use typesof().
		list/wont_accept = list()

	interacted(atom/a)
		if(!(ismob(a)))
			return FALSE

		if(!bag.contents.len)
			alert(a, "I don't have anything else!")
			return FALSE

		var/mob/m = a

		switch(alert(m, "Would you like to buy or sell items?", name, "Buy", "Sell", "Neither"))
			if("Buy")
				sales("Buy", m)

			if("Sell")
				sales("Sell", m)

	proc
		sales(mode, mob/m)
			if(mode == "Buy")
				if(m.bag.amount() >= m.bag.slots)
					alert(m, "You don't have room for anything else!")
					return FALSE

				var/list/shop = list()
				for(var/i = 1 to bag.contents.len)
					shop += "[i]. [bag.contents[i]]"

				var/choose = input(m, "Which item would you like to buy?", "Buy") in shop|null

				if(!choose)
					return FALSE

				var/place = text2num(copytext(choose, 1, findtext(choose, ".")))
				var/item/I = bag.contents[place]
				place = bag.contents[bag.contents[place]]
				var/amount = input(m, "How many [I][place > 1 ? "s" : ""] would you like to buy? [place] in stock.  Each sells for [I.value] Gold.", "Buy") as num|null

				if(!amount)
					return FALSE

				if(amount > place)
					amount = place

				if(m.bag.amount() + amount > m.bag.slots)
					amount = m.bag.slots - m.bag.amount()

				var/price = I.value * amount

				if(price > m.gold)
					alert(m, "You can't afford that!", "Buy")
					return FALSE

				switch(alert(m, "That's going to be [price] Gold for [amount] [I][amount > 1 ? "s" : ""].  Okay?", "Buy", "Okay.", "Never mind!"))
					if("Okay.")
						m.gold -= price
						gold += price
						var/item/add = new I.type(m)
						m.bag.add_item(add, amount)
						bag.remove_item(I, amount)
						alert(m, "Thank you very much.", "Buy")
						m.update_inventory()

			else if(mode == "Sell")
				var/list/shop = list()
				for(var/i = 1 to m.bag.contents.len)
					shop += "[i]. [m.bag.contents[i]]"

				var/choose = input(m, "Which item would you like to sell?", "Sell") in shop|null

				if(!choose)
					return FALSE

				var/place = text2num(copytext(choose, 1, findtext(choose, ".")))
				var/item/I = m.bag.contents[place]

				if(!(istype(I, sell_type)))
					alert(m, "I cannot accept this.")
					return FALSE

				if(I.type in wont_accept)
					alert(m, "I won't accept this.")
					return FALSE

				place = m.bag.contents[m.bag.contents[place]]

				// Items are sold for 80% of their original value
				var/price = round((I.value - (I.value * 0.20)))

				var/amount = input(m, "How many [I][place > 1 ? "s" : ""] would you like to sell? [place] in bag.  Each sells for [price] Gold.", "Sell") as num|null

				if(!amount)
					return FALSE

				if(amount > place)
					amount = place

				price = price * amount

				var/check = "Yes"

				if(price > gold)
					check = alert(m, "I do not have enough Gold to pay you full price for this.  Would you still like to sell it to me?", "Sell", "Yes", "No")
					if(check == "Yes")
						price = gold

				if(check == "Yes")

					switch(alert(m, "You're going to get [price] Gold for [amount] [I][amount > 1 ? "s" : ""].  Okay?", "Sell", "Okay.", "Never mind!"))
						if("Okay.")
							m.gold += price
							gold -= price
							var/item/add = new I.type(src)
							bag.add_item(add, amount)
							m.bag.remove_item(I, amount)
							alert(m, "Thank you very much.", "Sell")
							m.update_inventory()