/*
_items.dm

this is the control file for all items.  it is fairly simple.

remember to use the mod for all items that modify any stat.
potions use it, weapons use it, etc.

I recommend studying up and understanding this before trying to modify it.
*/

item
	parent_type = /obj
	icon = '\Icons/item.dmi'

	var
		value = 0

		// This is the stat it modifies.  It is CASE SENSITIVE.  Spell it exactly like the variable in question.
		stat

		// This is a percentage.  If it is a weapon, set this to a decimal(representing a percentage)
		// mod = 0.1 with stat = "strength" will give a 10% boost to strength.
		// mod is also used for potions.  Set it to the % boost to the stat.
		// This also allows for poisons.  Just make this negative.
		mod = 0

		mob/owner

		tmp/equipped = FALSE
		tmp/unbuff_amnt = 0

		// hand should either be "left" or "right".  "right" by default for weapons.
		hand = "right"

	New(mob/m)
		..()

		if(m)
			owner = m


	proc
		use()
			if(!owner)
				return FALSE

			var/add = owner.vars[stat] * mod
			owner.vars[stat] += add
			owner.bag.remove_item(src, 1)

			var/display_stat = stat

			if(stat == "hit_points")
				display_stat = "Hit Points"
			if(stat == "mana")
				display_stat = "Mana"

			owner << "Used [src], gaining [add] [display_stat]."


		equip()
			if(!owner)
				return FALSE

			if(istype(src, /item/potion))
				return use()

			// If their right(left) hand is occupied, we can't equip it.  If this item is equipped, unequip.  Otherwise return.
			if(owner.vars["[hand]_hand"])
				if(owner.vars["[hand]_hand"] == src)
					return unequip()
				else
					return FALSE

			// Equip it.
			owner.vars["[hand]_hand"] = src
			owner.overlays += src

			// Buff the owner.
			buff()
			equipped = TRUE

			owner << "<b>[src]</b> equipped."

		unequip()
			if(!owner)
				return FALSE

			if(istype(src, /item/potion))
				return FALSE

			// If they aren't holding this item, we can't unequip it.
			if(owner.vars["[hand]_hand"] != src)
				return FALSE

			// Unequip it.
			owner.vars["[hand]_hand"] = null
			owner.overlays -= src

			// Unbuff the owner.
			unbuff()
			equipped = FALSE

			owner << "<b>[src]</b> unequipped."

		buff(mob/m)
			if(!m)
				m = owner

			// Use unbuff_amnt to save how much their stat was increased.
			unbuff_amnt = m.vars[stat] * mod
			m.vars[stat] += unbuff_amnt

		unbuff(mob/m)
			if(!m)
				m = owner

			// Decrease their stat by the amount it was increased.
			// This way even if they increase their stat while having something equipped, the stat
			// won't bug up.
			m.vars[stat] -= unbuff_amnt
